"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const chalk_1 = require("chalk");
const cli_framework_1 = require("@ionic/cli-framework");
const cli_utils_1 = require("@ionic/cli-utils");
const utils_1 = require("@ionic/cli-utils/lib/integrations/cordova/utils");
const base_1 = require("./base");
class CompileCommand extends base_1.CordovaCommand {
    getMetadata() {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            return {
                name: 'compile',
                type: 'project',
                description: 'Compile native platform code',
                longDescription: `
Like running ${chalk_1.default.green('cordova compile')} directly, but provides friendly checks.
      `,
                exampleCommands: [
                    'ios',
                    'ios --device',
                    'android',
                ],
                inputs: [
                    {
                        name: 'platform',
                        description: `The platform to compile (${['android', 'ios'].map(v => chalk_1.default.green(v)).join(', ')})`,
                        validators: [cli_framework_1.validators.required],
                    },
                ],
                options: [
                    {
                        name: 'debug',
                        description: 'Create a Cordova debug build',
                        type: Boolean,
                        groups: [cli_utils_1.OptionGroup.Cordova],
                    },
                    {
                        name: 'release',
                        description: 'Create a Cordova release build',
                        type: Boolean,
                        groups: [cli_utils_1.OptionGroup.Cordova],
                    },
                    {
                        name: 'device',
                        description: 'Compile Cordova build to a device',
                        type: Boolean,
                        groups: [cli_utils_1.OptionGroup.Cordova],
                    },
                    {
                        name: 'emulator',
                        description: 'Compile Cordova build to an emulator',
                        type: Boolean,
                        groups: [cli_utils_1.OptionGroup.Cordova],
                    },
                ],
            };
        });
    }
    preRun(inputs, options) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            yield this.preRunChecks();
            if (!inputs[0]) {
                const platform = yield this.env.prompt({
                    type: 'input',
                    name: 'platform',
                    message: `What platform would you like to compile (${['android', 'ios'].map(v => chalk_1.default.green(v)).join(', ')}):`,
                });
                inputs[0] = platform.trim();
            }
            yield this.checkForPlatformInstallation(inputs[0]);
        });
    }
    run(inputs, options) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            const metadata = yield this.getMetadata();
            yield this.runCordova(utils_1.filterArgumentsForCordova(metadata, options), {});
        });
    }
}
exports.CompileCommand = CompileCommand;
