"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const chalk_1 = require("chalk");
const cli_framework_1 = require("@ionic/cli-framework");
const command_1 = require("@ionic/cli-utils/lib/command");
const errors_1 = require("@ionic/cli-utils/lib/errors");
class DoctorCheckCommand extends command_1.Command {
    getMetadata() {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            return {
                name: 'check',
                type: 'project',
                description: 'Check the health of your Ionic project',
                inputs: [
                    {
                        name: 'id',
                        description: 'The issue identifier',
                    },
                ],
            };
        });
    }
    run(inputs, options) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            const [id] = inputs;
            const { detectAndTreatAilment, getRegistry, treatAilments } = yield Promise.resolve().then(() => require('@ionic/cli-utils/lib/doctor/index'));
            const { Ailments } = yield Promise.resolve().then(() => require('@ionic/cli-utils/lib/doctor/ailments'));
            const registry = yield getRegistry(this.env);
            const ailmentIds = Ailments.ALL.map(Ailment => new Ailment(this.env).id);
            if (id) {
                cli_framework_1.validate(id, 'id', [cli_framework_1.contains(ailmentIds, {})]);
                const ailment = registry.get(id);
                if (!ailment) {
                    throw new errors_1.FatalException(`Issue not found by ID: ${chalk_1.default.green(id)}`);
                }
                yield detectAndTreatAilment(this.env, ailment);
            }
            else {
                yield treatAilments(this.env);
            }
        });
    }
}
exports.DoctorCheckCommand = DoctorCheckCommand;
