"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const chalk_1 = require("chalk");
const constants_1 = require("@ionic/cli-utils/constants");
const command_1 = require("@ionic/cli-utils/lib/command");
const errors_1 = require("@ionic/cli-utils/lib/errors");
const project_1 = require("@ionic/cli-utils/lib/project");
class GenerateCommand extends command_1.Command {
    getRunner() {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            if (!this.runner) {
                const { GenerateRunner } = yield Promise.resolve().then(() => require('@ionic/cli-utils/lib/generate'));
                this.runner = yield GenerateRunner.createFromProjectType(this.env, this.env.project.type);
            }
            return this.runner;
        });
    }
    getMetadata() {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            let projectMetadata;
            const longDescription = this.env.project.type
                ? chalk_1.default.red(`Generators are not supported in this project type (${chalk_1.default.bold(project_1.prettyProjectName(this.env.project.type))}).`)
                : chalk_1.default.red('Generators help is available within an Ionic project directory.');
            const metadata = {
                name: 'generate',
                type: 'project',
                description: 'Automatically create framework components',
                longDescription,
                groups: [constants_1.CommandGroup.Hidden],
            };
            try {
                const runner = yield this.getRunner();
                projectMetadata = yield runner.getCommandMetadata();
            }
            catch (e) {
                if (!(e instanceof errors_1.RunnerNotFoundException)) {
                    throw e;
                }
            }
            return Object.assign({}, metadata, projectMetadata);
        });
    }
    preRun(inputs, options) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            try {
                const runner = yield this.getRunner();
                yield runner.ensureCommandLine(inputs, options);
            }
            catch (e) {
                if (!(e instanceof errors_1.RunnerNotFoundException)) {
                    throw e;
                }
            }
        });
    }
    run(inputs, options) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            const runner = yield this.getRunner();
            const opts = runner.createOptionsFromCommandLine(inputs, options);
            yield runner.run(opts);
        });
    }
}
exports.GenerateCommand = GenerateCommand;
