"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const lodash = require("lodash");
const chalk_1 = require("chalk");
const cli_framework_1 = require("@ionic/cli-framework");
const cli_utils_1 = require("@ionic/cli-utils");
const namespace_1 = require("@ionic/cli-utils/lib/namespace");
const errors_1 = require("@ionic/cli-utils/lib/errors");
const project_1 = require("@ionic/cli-utils/lib/project");
class IonicNamespace extends namespace_1.Namespace {
    getMetadata() {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            return {
                name: 'ionic',
                description: '',
            };
        });
    }
    getNamespaces() {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            return new namespace_1.NamespaceMap([
                ['config', () => tslib_1.__awaiter(this, void 0, void 0, function* () { const { ConfigNamespace } = yield Promise.resolve().then(() => require('./config/index')); return new ConfigNamespace(this, this.env); })],
                ['cordova', () => tslib_1.__awaiter(this, void 0, void 0, function* () { const { CordovaNamespace } = yield Promise.resolve().then(() => require('./cordova/index')); return new CordovaNamespace(this, this.env); })],
                ['git', () => tslib_1.__awaiter(this, void 0, void 0, function* () { const { GitNamespace } = yield Promise.resolve().then(() => require('./git/index')); return new GitNamespace(this, this.env); })],
                ['ssh', () => tslib_1.__awaiter(this, void 0, void 0, function* () { const { SSHNamespace } = yield Promise.resolve().then(() => require('./ssh/index')); return new SSHNamespace(this, this.env); })],
                ['monitoring', () => tslib_1.__awaiter(this, void 0, void 0, function* () { const { MonitoringNamespace } = yield Promise.resolve().then(() => require('./monitoring/index')); return new MonitoringNamespace(this, this.env); })],
                ['doctor', () => tslib_1.__awaiter(this, void 0, void 0, function* () { const { DoctorNamespace } = yield Promise.resolve().then(() => require('./doctor/index')); return new DoctorNamespace(this, this.env); })],
                ['integrations', () => tslib_1.__awaiter(this, void 0, void 0, function* () { const { IntegrationsNamespace } = yield Promise.resolve().then(() => require('./integrations/index')); return new IntegrationsNamespace(this, this.env); })],
            ]);
        });
    }
    getCommands() {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            return new namespace_1.CommandMap([
                ['build', () => tslib_1.__awaiter(this, void 0, void 0, function* () { const { BuildCommand } = yield Promise.resolve().then(() => require('./build')); return new BuildCommand(this, this.env); })],
                ['docs', () => tslib_1.__awaiter(this, void 0, void 0, function* () { const { DocsCommand } = yield Promise.resolve().then(() => require('./docs')); return new DocsCommand(this, this.env); })],
                ['g', 'generate'],
                ['generate', () => tslib_1.__awaiter(this, void 0, void 0, function* () { const { GenerateCommand } = yield Promise.resolve().then(() => require('./generate')); return new GenerateCommand(this, this.env); })],
                ['help', () => tslib_1.__awaiter(this, void 0, void 0, function* () { const { HelpCommand } = yield Promise.resolve().then(() => require('./help')); return new HelpCommand(this, this.env); })],
                ['info', () => tslib_1.__awaiter(this, void 0, void 0, function* () { const { InfoCommand } = yield Promise.resolve().then(() => require('./info')); return new InfoCommand(this, this.env); })],
                ['ionitron', () => tslib_1.__awaiter(this, void 0, void 0, function* () { const { IonitronCommand } = yield Promise.resolve().then(() => require('./ionitron')); return new IonitronCommand(this, this.env); })],
                ['link', () => tslib_1.__awaiter(this, void 0, void 0, function* () { const { LinkCommand } = yield Promise.resolve().then(() => require('./link')); return new LinkCommand(this, this.env); })],
                ['login', () => tslib_1.__awaiter(this, void 0, void 0, function* () { const { LoginCommand } = yield Promise.resolve().then(() => require('./login')); return new LoginCommand(this, this.env); })],
                ['logout', () => tslib_1.__awaiter(this, void 0, void 0, function* () { const { LogoutCommand } = yield Promise.resolve().then(() => require('./logout')); return new LogoutCommand(this, this.env); })],
                ['serve', () => tslib_1.__awaiter(this, void 0, void 0, function* () { const { ServeCommand } = yield Promise.resolve().then(() => require('./serve')); return new ServeCommand(this, this.env); })],
                ['share', () => tslib_1.__awaiter(this, void 0, void 0, function* () { const { ShareCommand } = yield Promise.resolve().then(() => require('./share')); return new ShareCommand(this, this.env); })],
                ['signup', () => tslib_1.__awaiter(this, void 0, void 0, function* () { const { SignupCommand } = yield Promise.resolve().then(() => require('./signup')); return new SignupCommand(this, this.env); })],
                ['start', () => tslib_1.__awaiter(this, void 0, void 0, function* () { const { StartCommand } = yield Promise.resolve().then(() => require('./start')); return new StartCommand(this, this.env); })],
                ['state', () => tslib_1.__awaiter(this, void 0, void 0, function* () { const { StateCommand } = yield Promise.resolve().then(() => require('./state')); return new StateCommand(this, this.env); })],
                ['telemetry', () => tslib_1.__awaiter(this, void 0, void 0, function* () { const { TelemetryCommand } = yield Promise.resolve().then(() => require('./telemetry')); return new TelemetryCommand(this, this.env); })],
                ['version', () => tslib_1.__awaiter(this, void 0, void 0, function* () { const { VersionCommand } = yield Promise.resolve().then(() => require('./version')); return new VersionCommand(this, this.env); })],
                ['lab', () => tslib_1.__awaiter(this, void 0, void 0, function* () { const { LabCommand } = yield Promise.resolve().then(() => require('./serve')); return new LabCommand(this, this.env); })],
            ]);
        });
    }
    runCommand(argv, env) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            const pargs = cli_framework_1.stripOptions(argv, {});
            const location = yield this.locate(pargs);
            if (!cli_utils_1.isCommand(location.obj)) {
                const { showHelp } = yield Promise.resolve().then(() => require('@ionic/cli-utils/lib/help'));
                yield this.env.telemetry.sendCommand('ionic help', pargs);
                return showHelp(this.env, pargs);
            }
            const command = location.obj;
            const metadata = yield command.getMetadata();
            const fullNameParts = location.path.map(([p]) => p);
            if (metadata.options) {
                const optMap = metadataToCmdOptsEnv(metadata, fullNameParts.slice(1));
                // TODO: changes opt by reference, which is probably bad
                for (const [opt, envvar] of optMap.entries()) {
                    const envdefault = env[envvar];
                    if (typeof envdefault !== 'undefined') {
                        opt.default = opt.type === Boolean ? (envdefault && envdefault !== '0' ? true : false) : envdefault;
                    }
                }
            }
            const minimistOpts = cli_framework_1.metadataToParseArgsOptions(metadata);
            const options = cli_framework_1.parseArgs(lodash.drop(argv, location.path.length - 1), minimistOpts);
            const inputs = options._;
            if (!this.env.project.directory && metadata.type === 'project') {
                throw new errors_1.FatalException(`Sorry! ${chalk_1.default.green(fullNameParts.join(' '))} can only be run in an Ionic project directory.\n` +
                    `If this is a project you'd like to integrate with Ionic, create an ${chalk_1.default.bold(project_1.PROJECT_FILE)} file.`);
            }
            yield command.execute(inputs, options, { location });
        });
    }
}
exports.IonicNamespace = IonicNamespace;
function metadataToCmdOptsEnv(metadata, cmdNameParts) {
    const optMap = new Map();
    if (!metadata.options) {
        return optMap;
    }
    const prefix = `IONIC_CMDOPTS_${cmdNameParts.map(s => s.toUpperCase()).join('_')}`;
    for (const option of metadata.options) {
        optMap.set(option, `${prefix}_${option.name.toUpperCase().split('-').join('_')}`);
    }
    return optMap;
}
exports.metadataToCmdOptsEnv = metadataToCmdOptsEnv;
